@@ -27,7 +27,7 @@ describe 'aodh::client' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :client_package_name => 'python3-aodhclient' }
         when 'RedHat'
