@@ -28,20 +28,24 @@ describe 'aodh' do
           :control_exchange          => '<SERVICE DEFAULT>'
         )
         is_expected.to contain_oslo__messaging__rabbit('aodh_config').with(
-          :rabbit_use_ssl              => '<SERVICE DEFAULT>',
-          :heartbeat_timeout_threshold => '<SERVICE DEFAULT>',
-          :heartbeat_rate              => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread        => '<SERVICE DEFAULT>',
-          :kombu_reconnect_delay       => '<SERVICE DEFAULT>',
-          :kombu_failover_strategy     => '<SERVICE DEFAULT>',
-          :amqp_durable_queues         => '<SERVICE DEFAULT>',
-          :kombu_compression           => '<SERVICE DEFAULT>',
-          :kombu_ssl_ca_certs          => '<SERVICE DEFAULT>',
-          :kombu_ssl_certfile          => '<SERVICE DEFAULT>',
-          :kombu_ssl_keyfile           => '<SERVICE DEFAULT>',
-          :kombu_ssl_version           => '<SERVICE DEFAULT>',
-          :rabbit_ha_queues            => '<SERVICE DEFAULT>',
-          :rabbit_retry_interval       => '<SERVICE DEFAULT>',
+          :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
+          :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
+          :heartbeat_rate                  => '<SERVICE DEFAULT>',
+          :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+          :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
+          :kombu_failover_strategy         => '<SERVICE DEFAULT>',
+          :amqp_durable_queues             => '<SERVICE DEFAULT>',
+          :kombu_compression               => '<SERVICE DEFAULT>',
+          :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile               => '<SERVICE DEFAULT>',
+          :kombu_ssl_version               => '<SERVICE DEFAULT>',
+          :rabbit_ha_queues                => '<SERVICE DEFAULT>',
+          :rabbit_retry_interval           => '<SERVICE DEFAULT>',
+          :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
+          :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
+          :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
+          :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__amqp('aodh_config').with(
           :server_request_prefix => '<SERVICE DEFAULT>',
@@ -96,6 +100,10 @@ describe 'aodh' do
           :kombu_ssl_keyfile                  => '/etc/key',
           :kombu_ssl_version                  => 'TLSv1',
           :rabbit_ha_queues                   => true,
+          :rabbit_quorum_queue                => true,
+          :rabbit_quorum_delivery_limit       => 3,
+          :rabbit_quorum_max_memory_length    => 5,
+          :rabbit_quorum_max_memory_bytes     => 1073741824,
           :amqp_idle_timeout                  => '60',
           :amqp_trace                         => true,
           :amqp_ssl_ca_file                   => '/etc/ca.cert',
@@ -119,18 +127,22 @@ describe 'aodh' do
           :control_exchange          => 'aodh',
         )
         is_expected.to contain_oslo__messaging__rabbit('aodh_config').with(
-          :rabbit_use_ssl              => true,
-          :heartbeat_timeout_threshold => '60',
-          :heartbeat_rate              => '10',
-          :heartbeat_in_pthread        => true,
-          :kombu_reconnect_delay       => '5.0',
-          :amqp_durable_queues         => true,
-          :kombu_compression           => 'gzip',
-          :kombu_ssl_ca_certs          => '/etc/ca.cert',
-          :kombu_ssl_certfile          => '/etc/certfile',
-          :kombu_ssl_keyfile           => '/etc/key',
-          :kombu_ssl_version           => 'TLSv1',
-          :rabbit_ha_queues            => true,
+          :rabbit_use_ssl                  => true,
+          :heartbeat_timeout_threshold     => '60',
+          :heartbeat_rate                  => '10',
+          :heartbeat_in_pthread            => true,
+          :kombu_reconnect_delay           => '5.0',
+          :amqp_durable_queues             => true,
+          :kombu_compression               => 'gzip',
+          :kombu_ssl_ca_certs              => '/etc/ca.cert',
+          :kombu_ssl_certfile              => '/etc/certfile',
+          :kombu_ssl_keyfile               => '/etc/key',
+          :kombu_ssl_version               => 'TLSv1',
+          :rabbit_ha_queues                => true,
+          :rabbit_quorum_queue             => true,
+          :rabbit_quorum_delivery_limit    => 3,
+          :rabbit_quorum_max_memory_length => 5,
+          :rabbit_quorum_max_memory_bytes  => 1073741824,
         )
         is_expected.to contain_oslo__messaging__amqp('aodh_config').with(
           :idle_timeout  => '60',
